@@ -1,12 +1,13 @@
-use std::path::Path;
-use std::{env, fs, path::PathBuf, process::Command};
+use std::env;
+use std::fs;
+use std::path::PathBuf;
 
 fn link(name: &str, bundled: bool) {
     use std::env::var;
     let target = var("TARGET").unwrap();
     let target: Vec<_> = target.split('-').collect();
     if target.get(2) == Some(&"windows") {
-        println!("cargo:rustc-link-lib=dylib={name}");
+        println!("cargo:rustc-link-lib=dylib={}", name);
         if bundled && target.get(3) == Some(&"gnu") {
             let dir = var("CARGO_MANIFEST_DIR").unwrap();
             println!("cargo:rustc-link-search=native={}/{}", dir, target[0]);
@@ -16,7 +17,10 @@ fn link(name: &str, bundled: bool) {
 
 fn fail_on_empty_directory(name: &str) {
     if fs::read_dir(name).unwrap().count() == 0 {
-        println!("The `{name}` directory is empty, did you forget to pull the submodules?");
+        println!(
+            "The `{}` directory is empty, did you forget to pull the submodules?",
+            name
+        );
         println!("Try `git submodule update --init --recursive`");
         panic!();
     }
@@ -60,34 +64,23 @@ fn build_rocksdb() {
 
     if cfg!(feature = "lz4") {
         config.define("LZ4", Some("1"));
-        if let Some(path) = env::var_os("DEP_LZ4_INCLUDE") {
-            config.include(path);
-        }
+        config.include("lz4/lib/");
     }
 
     if cfg!(feature = "zstd") {
         config.define("ZSTD", Some("1"));
-        if let Some(path) = env::var_os("DEP_ZSTD_INCLUDE") {
-            config.include(path);
-        }
+        config.include("zstd/lib/");
+        config.include("zstd/lib/dictBuilder/");
     }
 
     if cfg!(feature = "zlib") {
         config.define("ZLIB", Some("1"));
-        if let Some(path) = env::var_os("DEP_Z_INCLUDE") {
-            config.include(path);
-        }
+        config.include("zlib/");
     }
 
     if cfg!(feature = "bzip2") {
         config.define("BZIP2", Some("1"));
-        if let Some(path) = env::var_os("DEP_BZIP2_INCLUDE") {
-            config.include(path);
-        }
-    }
-
-    if cfg!(feature = "rtti") {
-        config.define("USE_RTTI", Some("1"));
+        config.include("bzip2/");
     }
 
     config.include(".");
@@ -97,19 +90,21 @@ fn build_rocksdb() {
         .trim()
         .split('\n')
         .map(str::trim)
-        // We have a pre-generated a version of build_version.cc in the local directory
-        .filter(|file| !matches!(*file, "util/build_version.cc"))
         .collect::<Vec<&'static str>>();
 
-    if let (true, Ok(target_feature_value)) = (
-        target.contains("x86_64"),
-        env::var("CARGO_CFG_TARGET_FEATURE"),
-    ) {
+    // We have a pregenerated a version of build_version.cc in the local directory
+    lib_sources = lib_sources
+        .iter()
+        .cloned()
+        .filter(|&file| file != "util/build_version.cc")
+        .collect::<Vec<&'static str>>();
+
+    if target.contains("x86_64") {
         // This is needed to enable hardware CRC32C. Technically, SSE 4.2 is
         // only available since Intel Nehalem (about 2010) and AMD Bulldozer
         // (about 2011).
-        let target_features: Vec<_> = target_feature_value.split(',').collect();
-
+        let target_feature = env::var("CARGO_CFG_TARGET_FEATURE").unwrap();
+        let target_features: Vec<_> = target_feature.split(",").collect();
         if target_features.contains(&"sse2") {
             config.flag_if_supported("-msse2");
         }
@@ -118,35 +113,22 @@ fn build_rocksdb() {
         }
         if target_features.contains(&"sse4.2") {
             config.flag_if_supported("-msse4.2");
+            config.define("HAVE_SSE42", Some("1"));
         }
-        // Pass along additional target features as defined in
-        // build_tools/build_detect_platform.
-        if target_features.contains(&"avx2") {
-            config.flag_if_supported("-mavx2");
-        }
-        if target_features.contains(&"bmi1") {
-            config.flag_if_supported("-mbmi");
-        }
-        if target_features.contains(&"lzcnt") {
-            config.flag_if_supported("-mlzcnt");
-        }
-        if !target.contains("android") && target_features.contains(&"pclmulqdq") {
-            config.flag_if_supported("-mpclmul");
+
+        if !target.contains("android") {
+            if target_features.contains(&"pclmulqdq") {
+                config.define("HAVE_PCLMUL", Some("1"));
+                config.flag_if_supported("-mpclmul");
+            }
         }
     }
 
-    if target.contains("apple-ios") {
-        config.define("OS_MACOSX", None);
+    if target.contains("aarch64") {
+        lib_sources.push("util/crc32c_arm64.cc")
+    }
 
-        config.define("IOS_CROSS_COMPILE", None);
-        config.define("PLATFORM", "IOS");
-        config.define("NIOSTATS_CONTEXT", None);
-        config.define("NPERF_CONTEXT", None);
-        config.define("ROCKSDB_PLATFORM_POSIX", None);
-        config.define("ROCKSDB_LIB_IO_POSIX", None);
-
-        env::set_var("IPHONEOS_DEPLOYMENT_TARGET", "12.0");
-    } else if target.contains("darwin") {
+    if target.contains("darwin") {
         config.define("OS_MACOSX", None);
         config.define("ROCKSDB_PLATFORM_POSIX", None);
         config.define("ROCKSDB_LIB_IO_POSIX", None);
@@ -170,7 +152,6 @@ fn build_rocksdb() {
         config.define("_MBCS", None);
         config.define("WIN64", None);
         config.define("NOMINMAX", None);
-        config.define("ROCKSDB_WINDOWS_UTF8_FILENAMES", None);
 
         if &target == "x86_64-pc-windows-gnu" {
             // Tell MinGW to create localtime_r wrapper of localtime_s function.
@@ -196,64 +177,33 @@ fn build_rocksdb() {
             .collect::<Vec<&'static str>>();
 
         // Add Windows-specific sources
-        lib_sources.extend([
-            "port/win/env_default.cc",
-            "port/win/port_win.cc",
-            "port/win/xpress_win.cc",
-            "port/win/io_win.cc",
-            "port/win/win_thread.cc",
-            "port/win/env_win.cc",
-            "port/win/win_logger.cc",
-        ]);
-
-        if cfg!(feature = "jemalloc") {
-            lib_sources.push("port/win/win_jemalloc.cc");
-        }
+        lib_sources.push("port/win/port_win.cc");
+        lib_sources.push("port/win/env_win.cc");
+        lib_sources.push("port/win/env_default.cc");
+        lib_sources.push("port/win/win_logger.cc");
+        lib_sources.push("port/win/io_win.cc");
+        lib_sources.push("port/win/win_thread.cc");
     }
 
     config.define("ROCKSDB_SUPPORT_THREAD_LOCAL", None);
 
-    if cfg!(feature = "jemalloc") {
-        config.define("WITH_JEMALLOC", "ON");
-    }
-
-    #[cfg(feature = "io-uring")]
-    if target.contains("linux") {
-        pkg_config::probe_library("liburing")
-            .expect("The io-uring feature was requested but the library is not available");
-        config.define("ROCKSDB_IOURING_PRESENT", Some("1"));
-    }
-
-    if env::var("CARGO_CFG_TARGET_POINTER_WIDTH").unwrap() != "64" {
-        config.define("_FILE_OFFSET_BITS", Some("64"));
-        config.define("_LARGEFILE64_SOURCE", Some("1"));
-    }
-
     if target.contains("msvc") {
         config.flag("-EHsc");
-        config.flag("-std:c++17");
     } else {
         config.flag(&cxx_standard());
-        // matches the flags in CMakeLists.txt from rocksdb
-        config.flag("-Wsign-compare");
-        config.flag("-Wshadow");
+        // this was breaking the build on travis due to
+        // > 4mb of warnings emitted.
         config.flag("-Wno-unused-parameter");
-        config.flag("-Wno-unused-variable");
-        config.flag("-Woverloaded-virtual");
-        config.flag("-Wnon-virtual-dtor");
-        config.flag("-Wno-missing-field-initializers");
-        config.flag("-Wno-strict-aliasing");
-        config.flag("-Wno-invalid-offsetof");
     }
 
     for file in lib_sources {
-        config.file(format!("rocksdb/{file}"));
+        let file = "rocksdb/".to_string() + file;
+        config.file(&file);
     }
 
     config.file("build_version.cc");
 
     config.cpp(true);
-    config.flag_if_supported("-std=c++17");
     config.compile("librocksdb.a");
 }
 
@@ -286,20 +236,105 @@ fn build_snappy() {
     config.compile("libsnappy.a");
 }
 
+fn build_lz4() {
+    let mut compiler = cc::Build::new();
+
+    compiler
+        .file("lz4/lib/lz4.c")
+        .file("lz4/lib/lz4frame.c")
+        .file("lz4/lib/lz4hc.c")
+        .file("lz4/lib/xxhash.c");
+
+    compiler.opt_level(3);
+
+    let target = env::var("TARGET").unwrap();
+
+    if &target == "i686-pc-windows-gnu" {
+        compiler.flag("-fno-tree-vectorize");
+    }
+
+    compiler.compile("liblz4.a");
+}
+
+fn build_zstd() {
+    let mut compiler = cc::Build::new();
+
+    compiler.include("zstd/lib/");
+    compiler.include("zstd/lib/common");
+    compiler.include("zstd/lib/legacy");
+
+    let globs = &[
+        "zstd/lib/common/*.c",
+        "zstd/lib/compress/*.c",
+        "zstd/lib/decompress/*.c",
+        "zstd/lib/dictBuilder/*.c",
+        "zstd/lib/legacy/*.c",
+    ];
+
+    for pattern in globs {
+        for path in glob::glob(pattern).unwrap() {
+            let path = path.unwrap();
+            compiler.file(path);
+        }
+    }
+
+    compiler.opt_level(3);
+    compiler.extra_warnings(false);
+
+    compiler.define("ZSTD_LIB_DEPRECATED", Some("0"));
+    compiler.compile("libzstd.a");
+}
+
+fn build_zlib() {
+    let mut compiler = cc::Build::new();
+
+    let globs = &["zlib/*.c"];
+
+    for pattern in globs {
+        for path in glob::glob(pattern).unwrap() {
+            let path = path.unwrap();
+            compiler.file(path);
+        }
+    }
+
+    compiler.flag_if_supported("-Wno-implicit-function-declaration");
+    compiler.opt_level(3);
+    compiler.extra_warnings(false);
+    compiler.compile("libz.a");
+}
+
+fn build_bzip2() {
+    let mut compiler = cc::Build::new();
+
+    compiler
+        .file("bzip2/blocksort.c")
+        .file("bzip2/bzlib.c")
+        .file("bzip2/compress.c")
+        .file("bzip2/crctable.c")
+        .file("bzip2/decompress.c")
+        .file("bzip2/huffman.c")
+        .file("bzip2/randtable.c");
+
+    compiler
+        .define("_FILE_OFFSET_BITS", Some("64"))
+        .define("BZ_NO_STDIO", None);
+
+    compiler.extra_warnings(false);
+    compiler.opt_level(3);
+    compiler.extra_warnings(false);
+    compiler.compile("libbz2.a");
+}
+
 fn try_to_find_and_link_lib(lib_name: &str) -> bool {
-    println!("cargo:rerun-if-env-changed={lib_name}_COMPILE");
-    if let Ok(v) = env::var(format!("{lib_name}_COMPILE")) {
+    if let Ok(v) = env::var(&format!("{}_COMPILE", lib_name)) {
         if v.to_lowercase() == "true" || v == "1" {
             return false;
         }
     }
 
-    println!("cargo:rerun-if-env-changed={lib_name}_LIB_DIR");
-    println!("cargo:rerun-if-env-changed={lib_name}_STATIC");
-
-    if let Ok(lib_dir) = env::var(format!("{lib_name}_LIB_DIR")) {
-        println!("cargo:rustc-link-search=native={lib_dir}");
-        let mode = match env::var_os(format!("{lib_name}_STATIC")) {
+    if let Ok(lib_dir) = env::var(&format!("{}_LIB_DIR", lib_name)) {
+        println!("cargo:rustc-link-search=native={}", lib_dir);
+        let mode = match env::var_os(&format!("{}_STATIC", lib_name)) {
             Some(_) => "static",
             None => "dylib",
         };
@@ -310,39 +345,16 @@ fn try_to_find_and_link_lib(lib_name: &str) -> bool {
 }
 
 fn cxx_standard() -> String {
-    env::var("ROCKSDB_CXX_STD").map_or("-std=c++17".to_owned(), |cxx_std| {
+    env::var("ROCKSDB_CXX_STD").map_or("-std=c++11".to_owned(), |cxx_std| {
         if !cxx_std.starts_with("-std=") {
-            format!("-std={cxx_std}")
+            format!("-std={}", cxx_std)
         } else {
             cxx_std
         }
     })
 }
 
-fn update_submodules() {
-    let program = "git";
-    let dir = "../";
-    let args = ["submodule", "update", "--init"];
-    println!(
-        "Running command: \"{} {}\" in dir: {}",
-        program,
-        args.join(" "),
-        dir
-    );
-    let ret = Command::new(program).current_dir(dir).args(args).status();
-
-    match ret.map(|status| (status.success(), status.code())) {
-        Ok((true, _)) => (),
-        Ok((false, Some(c))) => panic!("Command failed with error code {}", c),
-        Ok((false, None)) => panic!("Command got killed"),
-        Err(e) => panic!("Command failed with error: {}", e),
-    }
-}
-
 fn main() {
-    if !Path::new("rocksdb/AUTHORS").exists() {
-        update_submodules();
-    }
     bindgen_rocksdb();
 
     if !try_to_find_and_link_lib("ROCKSDB") {
@@ -363,13 +375,24 @@ fn main() {
         fail_on_empty_directory("snappy");
         build_snappy();
     }
-
-    // Allow dependent crates to locate the sources and output directory of
-    // this crate. Notably, this allows a dependent crate to locate the RocksDB
-    // sources and built archive artifacts provided by this crate.
-    println!(
-        "cargo:cargo_manifest_dir={}",
-        env::var("CARGO_MANIFEST_DIR").unwrap()
-    );
-    println!("cargo:out_dir={}", env::var("OUT_DIR").unwrap());
+    if cfg!(feature = "lz4") && !try_to_find_and_link_lib("LZ4") {
+        println!("cargo:rerun-if-changed=lz4/");
+        fail_on_empty_directory("lz4");
+        build_lz4();
+    }
+    if cfg!(feature = "zstd") && !try_to_find_and_link_lib("ZSTD") {
+        println!("cargo:rerun-if-changed=zstd/");
+        fail_on_empty_directory("zstd");
+        build_zstd();
+    }
+    if cfg!(feature = "zlib") && !try_to_find_and_link_lib("Z") {
+        println!("cargo:rerun-if-changed=zlib/");
+        fail_on_empty_directory("zlib");
+        build_zlib();
+    }
+    if cfg!(feature = "bzip2") && !try_to_find_and_link_lib("BZ2") {
+        println!("cargo:rerun-if-changed=bzip2/");
+        fail_on_empty_directory("bzip2");
+        build_bzip2();
+    }
 }
