@@ -5,10 +5,10 @@
 
 #pragma once
 
+#if !defined(ROCKSDB_LITE)
 
 #include <string>
 
-#include "rocksdb/customizable.h"
 #include "rocksdb/env.h"
 #include "rocksdb/file_system.h"
 #include "rocksdb/rocksdb_namespace.h"
@@ -23,9 +23,6 @@ struct ConfigOptions;
 // read from disk.
 Env* NewEncryptedEnv(Env* base_env,
                      const std::shared_ptr<EncryptionProvider>& provider);
-std::shared_ptr<FileSystem> NewEncryptedFS(
-    const std::shared_ptr<FileSystem>& base_fs,
-    const std::shared_ptr<EncryptionProvider>& provider);
 
 // BlockAccessCipherStream is the base class for any cipher stream that
 // supports random access at block level (without requiring data from other
@@ -61,11 +58,7 @@ class BlockAccessCipherStream {
 };
 
 // BlockCipher
-//
-// Exceptions MUST NOT propagate out of overridden functions into RocksDB,
-// because RocksDB is not exception-safe. This could cause undefined behavior
-// including data loss, unreported corruption, deadlocks, and more.
-class BlockCipher : public Customizable {
+class BlockCipher {
  public:
   virtual ~BlockCipher(){};
 
@@ -87,12 +80,12 @@ class BlockCipher : public Customizable {
                                  const std::string& value,
                                  std::shared_ptr<BlockCipher>* result);
 
-  static const char* Type() { return "BlockCipher"; }
   // Short-cut method to create a ROT13 BlockCipher.
   // This cipher is only suitable for test purposes and should not be used in
   // production!!!
   static std::shared_ptr<BlockCipher> NewROT13Cipher(size_t block_size);
 
+  virtual const char* Name() const = 0;
   // BlockSize returns the size of each block supported by this cipher stream.
   virtual size_t BlockSize() = 0;
 
@@ -108,11 +101,7 @@ class BlockCipher : public Customizable {
 // The encryption provider is used to create a cipher stream for a specific
 // file. The returned cipher stream will be used for actual
 // encryption/decryption actions.
-//
-// Exceptions MUST NOT propagate out of overridden functions into RocksDB,
-// because RocksDB is not exception-safe. This could cause undefined behavior
-// including data loss, unreported corruption, deadlocks, and more.
-class EncryptionProvider : public Customizable {
+class EncryptionProvider {
  public:
   virtual ~EncryptionProvider(){};
 
@@ -120,14 +109,14 @@ class EncryptionProvider : public Customizable {
   // The value describes the type of provider (and potentially optional
   // configuration parameters) used to create this provider.
   // For example, if the value is "CTR", a CTREncryptionProvider will be
-  // created. If the value is ends with "://test" (e.g CTR://test"), the
-  // provider will be initialized in "TEST" mode prior to being returned.
+  // created. If the value is preceded by "test://" (e.g test://CTR"), the
+  // TEST_Initialize method will be invoked prior to returning the provider.
   //
   // @param config_options  Options to control how this provider is created
   //                        and initialized.
   // @param value  The value might be:
   //   - CTR         Create a CTR provider
-  //   - CTR://test Create a CTR provider and initialize it for tests.
+  //   - test://CTR Create a CTR provider and initialize it for tests.
   // @param result The new provider object
   // @return OK if the provider was successfully created
   // @return NotFound if an invalid name was specified in the value
@@ -136,12 +125,13 @@ class EncryptionProvider : public Customizable {
                                  const std::string& value,
                                  std::shared_ptr<EncryptionProvider>* result);
 
-  static const char* Type() { return "EncryptionProvider"; }
-
   // Short-cut method to create a CTR-provider
   static std::shared_ptr<EncryptionProvider> NewCTRProvider(
       const std::shared_ptr<BlockCipher>& cipher);
 
+  // Returns the name of this EncryptionProvider
+  virtual const char* Name() const = 0;
+
   // GetPrefixLength returns the length of the prefix that is added to every
   // file and used for storing encryption options. For optimal performance, the
   // prefix length should be a multiple of the page size.
@@ -175,6 +165,11 @@ class EncryptionProvider : public Customizable {
   // or not a file is encrypted by this provider.  The maker will also be part
   // of any encryption prefix for this provider.
   virtual std::string GetMarker() const { return ""; }
+
+ protected:
+  // Optional method to initialize an EncryptionProvider in the TEST
+  // environment.
+  virtual Status TEST_Initialize() { return Status::OK(); }
 };
 
 class EncryptedSequentialFile : public FSSequentialFile {
@@ -328,10 +323,6 @@ class EncryptedWritableFile : public FSWritableFile {
                             const IOOptions& options,
                             IODebugContext* dbg) override;
 
-  // true if Sync() and Fsync() are safe to call concurrently with Append()
-  // and Flush().
-  bool IsSyncThreadSafe() const override;
-
   // Indicates the upper layers if the current WritableFile implementation
   // uses direct IO.
   bool use_direct_io() const override;
@@ -375,11 +366,6 @@ class EncryptedWritableFile : public FSWritableFile {
   void PrepareWrite(size_t offset, size_t len, const IOOptions& options,
                     IODebugContext* dbg) override;
 
-  void SetPreallocationBlockSize(size_t size) override;
-
-  void GetPreallocationStatus(size_t* block_size,
-                              size_t* last_allocated_block) override;
-
   // Pre-allocates space for a file.
   IOStatus Allocate(uint64_t offset, uint64_t len, const IOOptions& options,
                     IODebugContext* dbg) override;
@@ -450,14 +436,7 @@ class EncryptedFileSystem : public FileSystemWrapper {
   // otherwise
   virtual Status AddCipher(const std::string& descriptor, const char* cipher,
                            size_t len, bool for_write) = 0;
-  static const char* kClassName() { return "EncryptedFileSystem"; }
-  bool IsInstanceOf(const std::string& name) const override {
-    if (name == kClassName()) {
-      return true;
-    } else {
-      return FileSystemWrapper::IsInstanceOf(name);
-    }
-  }
 };
 }  // namespace ROCKSDB_NAMESPACE
 
+#endif  // !defined(ROCKSDB_LITE)
