@@ -3,6 +3,7 @@
 //  COPYING file in the root directory) and Apache 2.0 License
 //  (found in the LICENSE.Apache file in the root directory).
 
+#ifndef ROCKSDB_LITE
 
 #ifndef GFLAGS
 #include <cstdio>
@@ -18,7 +19,6 @@ int main() {
 #include <vector>
 
 #include "memory/arena.h"
-#include "rocksdb/db.h"
 #include "table/cuckoo/cuckoo_table_builder.h"
 #include "table/cuckoo/cuckoo_table_factory.h"
 #include "table/cuckoo/cuckoo_table_reader.h"
@@ -32,12 +32,11 @@ int main() {
 
 using GFLAGS_NAMESPACE::ParseCommandLineFlags;
 
-DEFINE_string(file_dir, "",
-              "Directory where the files will be created"
-              " for benchmark. Added for using tmpfs.");
+DEFINE_string(file_dir, "", "Directory where the files will be created"
+    " for benchmark. Added for using tmpfs.");
 DEFINE_bool(enable_perf, false, "Run Benchmark Tests too.");
 DEFINE_bool(write, false,
-            "Should write new values to file in performance tests?");
+    "Should write new values to file in performance tests?");
 DEFINE_bool(identity_as_first_hash, true, "use identity as first hash");
 
 namespace ROCKSDB_NAMESPACE {
@@ -45,10 +44,10 @@ namespace ROCKSDB_NAMESPACE {
 namespace {
 const uint32_t kNumHashFunc = 10;
 // Methods, variables related to Hash functions.
-std::unordered_map<std::string, std::vector<uint64_t> > hash_map;
+std::unordered_map<std::string, std::vector<uint64_t>> hash_map;
 
 void AddHashLookups(const std::string& s, uint64_t bucket_id,
-                    uint32_t num_hash_fun) {
+        uint32_t num_hash_fun) {
   std::vector<uint64_t> v;
   for (uint32_t i = 0; i < num_hash_fun; i++) {
     v.push_back(bucket_id + i);
@@ -110,7 +109,7 @@ class CuckooReaderTest : public testing::Test {
     std::unique_ptr<RandomAccessFileReader> file_reader;
     ASSERT_OK(RandomAccessFileReader::Create(
         env->GetFileSystem(), fname, file_options, &file_reader, nullptr));
-    const ImmutableOptions ioptions(options);
+    const ImmutableCFOptions ioptions(options);
     CuckooTableReader reader(ioptions, std::move(file_reader), file_size, ucomp,
                              GetSliceHash);
     ASSERT_OK(reader.status());
@@ -119,8 +118,7 @@ class CuckooReaderTest : public testing::Test {
       PinnableSlice value;
       GetContext get_context(ucomp, nullptr, nullptr, nullptr,
                              GetContext::kNotFound, Slice(user_keys[i]), &value,
-                             nullptr, nullptr, nullptr, nullptr, true, nullptr,
-                             nullptr);
+                             nullptr, nullptr, true, nullptr, nullptr);
       ASSERT_OK(
           reader.Get(ReadOptions(), Slice(keys[i]), &get_context, nullptr));
       ASSERT_STREQ(values[i].c_str(), value.data());
@@ -128,8 +126,8 @@ class CuckooReaderTest : public testing::Test {
   }
   void UpdateKeys(bool with_zero_seqno) {
     for (uint32_t i = 0; i < num_items; i++) {
-      ParsedInternalKey ikey(user_keys[i], with_zero_seqno ? 0 : i + 1000,
-                             kTypeValue);
+      ParsedInternalKey ikey(user_keys[i],
+          with_zero_seqno ? 0 : i + 1000, kTypeValue);
       keys[i].clear();
       AppendInternalKey(&keys[i], ikey);
     }
@@ -139,7 +137,7 @@ class CuckooReaderTest : public testing::Test {
     std::unique_ptr<RandomAccessFileReader> file_reader;
     ASSERT_OK(RandomAccessFileReader::Create(
         env->GetFileSystem(), fname, file_options, &file_reader, nullptr));
-    const ImmutableOptions ioptions(options);
+    const ImmutableCFOptions ioptions(options);
     CuckooTableReader reader(ioptions, std::move(file_reader), file_size, ucomp,
                              GetSliceHash);
     ASSERT_OK(reader.status());
@@ -189,11 +187,11 @@ class CuckooReaderTest : public testing::Test {
                             TableReaderCaller::kUncategorized);
     ASSERT_OK(it->status());
     ASSERT_TRUE(!it->Valid());
-    it->Seek(keys[num_items / 2]);
+    it->Seek(keys[num_items/2]);
     ASSERT_TRUE(it->Valid());
     ASSERT_OK(it->status());
-    ASSERT_TRUE(keys[num_items / 2] == it->key());
-    ASSERT_TRUE(values[num_items / 2] == it->value());
+    ASSERT_TRUE(keys[num_items/2] == it->key());
+    ASSERT_TRUE(values[num_items/2] == it->value());
     ASSERT_OK(it->status());
     it->~InternalIterator();
   }
@@ -211,7 +209,7 @@ class CuckooReaderTest : public testing::Test {
 
 TEST_F(CuckooReaderTest, FileNotMmaped) {
   options.allow_mmap_reads = false;
-  ImmutableOptions ioptions(options);
+  ImmutableCFOptions ioptions(options);
   CuckooTableReader reader(ioptions, nullptr, 0, nullptr, nullptr);
   ASSERT_TRUE(reader.status().IsInvalidArgument());
   ASSERT_STREQ("File is not mmaped", reader.status().getState());
@@ -249,7 +247,7 @@ TEST_F(CuckooReaderTest, WhenKeyExistsWithUint64Comparator) {
   fname = test::PerThreadDBPath("CuckooReaderUint64_WhenKeyExists");
   for (uint64_t i = 0; i < num_items; i++) {
     user_keys[i].resize(8);
-    memcpy(user_keys[i].data(), static_cast<void*>(&i), 8);
+    memcpy(&user_keys[i][0], static_cast<void*>(&i), 8);
     ParsedInternalKey ikey(user_keys[i], i + 1000, kTypeValue);
     AppendInternalKey(&keys[i], ikey);
     values[i] = "value" + NumToStr(i);
@@ -273,7 +271,7 @@ TEST_F(CuckooReaderTest, WhenKeyExistsWithUint64Comparator) {
 }
 
 TEST_F(CuckooReaderTest, CheckIterator) {
-  SetUp(2 * kNumHashFunc);
+  SetUp(2*kNumHashFunc);
   fname = test::PerThreadDBPath("CuckooReader_CheckIterator");
   for (uint64_t i = 0; i < num_items; i++) {
     user_keys[i] = "key" + NumToStr(i);
@@ -281,7 +279,7 @@ TEST_F(CuckooReaderTest, CheckIterator) {
     AppendInternalKey(&keys[i], ikey);
     values[i] = "value" + NumToStr(i);
     // Give disjoint hash values, in reverse order.
-    AddHashLookups(user_keys[i], num_items - i - 1, kNumHashFunc);
+    AddHashLookups(user_keys[i], num_items-i-1, kNumHashFunc);
   }
   CreateCuckooFileAndCheckReader();
   CheckIterator();
@@ -292,16 +290,16 @@ TEST_F(CuckooReaderTest, CheckIterator) {
 }
 
 TEST_F(CuckooReaderTest, CheckIteratorUint64) {
-  SetUp(2 * kNumHashFunc);
+  SetUp(2*kNumHashFunc);
   fname = test::PerThreadDBPath("CuckooReader_CheckIterator");
   for (uint64_t i = 0; i < num_items; i++) {
     user_keys[i].resize(8);
-    memcpy(user_keys[i].data(), static_cast<void*>(&i), 8);
+    memcpy(&user_keys[i][0], static_cast<void*>(&i), 8);
     ParsedInternalKey ikey(user_keys[i], 1000, kTypeValue);
     AppendInternalKey(&keys[i], ikey);
     values[i] = "value" + NumToStr(i);
     // Give disjoint hash values, in reverse order.
-    AddHashLookups(user_keys[i], num_items - i - 1, kNumHashFunc);
+    AddHashLookups(user_keys[i], num_items-i-1, kNumHashFunc);
   }
   CreateCuckooFileAndCheckReader(test::Uint64Comparator());
   CheckIterator(test::Uint64Comparator());
@@ -330,7 +328,7 @@ TEST_F(CuckooReaderTest, WhenKeyNotFound) {
   ASSERT_OK(RandomAccessFileReader::Create(
       env->GetFileSystem(), fname, file_options, &file_reader, nullptr));
 
-  const ImmutableOptions ioptions(options);
+  const ImmutableCFOptions ioptions(options);
   CuckooTableReader reader(ioptions, std::move(file_reader), file_size, ucmp,
                            GetSliceHash);
   ASSERT_OK(reader.status());
@@ -342,8 +340,8 @@ TEST_F(CuckooReaderTest, WhenKeyNotFound) {
   AppendInternalKey(&not_found_key, ikey);
   PinnableSlice value;
   GetContext get_context(ucmp, nullptr, nullptr, nullptr, GetContext::kNotFound,
-                         Slice(not_found_key), &value, nullptr, nullptr,
-                         nullptr, nullptr, true, nullptr, nullptr);
+                         Slice(not_found_key), &value, nullptr, nullptr, true,
+                         nullptr, nullptr);
   ASSERT_OK(
       reader.Get(ReadOptions(), Slice(not_found_key), &get_context, nullptr));
   ASSERT_TRUE(value.empty());
@@ -357,8 +355,7 @@ TEST_F(CuckooReaderTest, WhenKeyNotFound) {
   value.Reset();
   GetContext get_context2(ucmp, nullptr, nullptr, nullptr,
                           GetContext::kNotFound, Slice(not_found_key2), &value,
-                          nullptr, nullptr, nullptr, nullptr, true, nullptr,
-                          nullptr);
+                          nullptr, nullptr, true, nullptr, nullptr);
   ASSERT_OK(
       reader.Get(ReadOptions(), Slice(not_found_key2), &get_context2, nullptr));
   ASSERT_TRUE(value.empty());
@@ -366,15 +363,15 @@ TEST_F(CuckooReaderTest, WhenKeyNotFound) {
 
   // Test read when key is unused key.
   std::string unused_key =
-      reader.GetTableProperties()->user_collected_properties.at(
-          CuckooTablePropertyNames::kEmptyKey);
+    reader.GetTableProperties()->user_collected_properties.at(
+    CuckooTablePropertyNames::kEmptyKey);
   // Add hash values that map to empty buckets.
-  AddHashLookups(ExtractUserKey(unused_key).ToString(), kNumHashFunc,
-                 kNumHashFunc);
+  AddHashLookups(ExtractUserKey(unused_key).ToString(),
+      kNumHashFunc, kNumHashFunc);
   value.Reset();
-  GetContext get_context3(
-      ucmp, nullptr, nullptr, nullptr, GetContext::kNotFound, Slice(unused_key),
-      &value, nullptr, nullptr, nullptr, nullptr, true, nullptr, nullptr);
+  GetContext get_context3(ucmp, nullptr, nullptr, nullptr,
+                          GetContext::kNotFound, Slice(unused_key), &value,
+                          nullptr, nullptr, true, nullptr, nullptr);
   ASSERT_OK(
       reader.Get(ReadOptions(), Slice(unused_key), &get_context3, nullptr));
   ASSERT_TRUE(value.empty());
@@ -402,13 +399,13 @@ std::string GetFileName(uint64_t num) {
     FLAGS_file_dir = test::TmpDir();
   }
   return test::PerThreadDBPath(FLAGS_file_dir, "cuckoo_read_benchmark") +
-         std::to_string(num / 1000000) + "Mkeys";
+         ToString(num / 1000000) + "Mkeys";
 }
 
 // Create last level file as we are interested in measuring performance of
 // last level file only.
-void WriteFile(const std::vector<std::string>& keys, const uint64_t num,
-               double hash_ratio) {
+void WriteFile(const std::vector<std::string>& keys,
+    const uint64_t num, double hash_ratio) {
   Options options;
   options.allow_mmap_reads = true;
   const auto& fs = options.env->GetFileSystem();
@@ -425,7 +422,7 @@ void WriteFile(const std::vector<std::string>& keys, const uint64_t num,
   ASSERT_OK(builder.status());
   for (uint64_t key_idx = 0; key_idx < num; ++key_idx) {
     // Value is just a part of key.
-    builder.Add(Slice(keys[key_idx]), Slice(keys[key_idx].data(), 4));
+    builder.Add(Slice(keys[key_idx]), Slice(&keys[key_idx][0], 4));
     ASSERT_EQ(builder.NumEntries(), key_idx + 1);
     ASSERT_OK(builder.status());
   }
@@ -440,7 +437,7 @@ void WriteFile(const std::vector<std::string>& keys, const uint64_t num,
   ASSERT_OK(RandomAccessFileReader::Create(fs, fname, file_options,
                                            &file_reader, nullptr));
 
-  const ImmutableOptions ioptions(options);
+  const ImmutableCFOptions ioptions(options);
   CuckooTableReader reader(ioptions, std::move(file_reader), file_size,
                            test::Uint64Comparator(), nullptr);
   ASSERT_OK(reader.status());
@@ -449,12 +446,12 @@ void WriteFile(const std::vector<std::string>& keys, const uint64_t num,
   // Assume only the fast path is triggered
   GetContext get_context(nullptr, nullptr, nullptr, nullptr,
                          GetContext::kNotFound, Slice(), &value, nullptr,
-                         nullptr, nullptr, true, nullptr, nullptr);
+                         nullptr, true, nullptr, nullptr);
   for (uint64_t i = 0; i < num; ++i) {
     value.Reset();
     value.clear();
     ASSERT_OK(reader.Get(r_options, Slice(keys[i]), &get_context, nullptr));
-    ASSERT_TRUE(Slice(keys[i]) == Slice(keys[i].data(), 4));
+    ASSERT_TRUE(Slice(keys[i]) == Slice(&keys[i][0], 4));
   }
 }
 
@@ -473,21 +470,18 @@ void ReadKeys(uint64_t num, uint32_t batch_size) {
   ASSERT_OK(RandomAccessFileReader::Create(fs, fname, file_options,
                                            &file_reader, nullptr));
 
-  const ImmutableOptions ioptions(options);
+  const ImmutableCFOptions ioptions(options);
   CuckooTableReader reader(ioptions, std::move(file_reader), file_size,
                            test::Uint64Comparator(), nullptr);
   ASSERT_OK(reader.status());
   const UserCollectedProperties user_props =
-      reader.GetTableProperties()->user_collected_properties;
+    reader.GetTableProperties()->user_collected_properties;
   const uint32_t num_hash_fun = *reinterpret_cast<const uint32_t*>(
       user_props.at(CuckooTablePropertyNames::kNumHashFunc).data());
   const uint64_t table_size = *reinterpret_cast<const uint64_t*>(
       user_props.at(CuckooTablePropertyNames::kHashTableSize).data());
-  fprintf(stderr,
-          "With %" PRIu64
-          " items, utilization is %.2f%%, number of"
-          " hash functions: %u.\n",
-          num, num * 100.0 / (table_size), num_hash_fun);
+  fprintf(stderr, "With %" PRIu64 " items, utilization is %.2f%%, number of"
+      " hash functions: %u.\n", num, num * 100.0 / (table_size), num_hash_fun);
   ReadOptions r_options;
 
   std::vector<uint64_t> keys;
@@ -501,14 +495,14 @@ void ReadKeys(uint64_t num, uint32_t batch_size) {
   // Assume only the fast path is triggered
   GetContext get_context(nullptr, nullptr, nullptr, nullptr,
                          GetContext::kNotFound, Slice(), &value, nullptr,
-                         nullptr, nullptr, true, nullptr, nullptr);
+                         nullptr, true, nullptr, nullptr);
   uint64_t start_time = env->NowMicros();
   if (batch_size > 0) {
     for (uint64_t i = 0; i < num; i += batch_size) {
-      for (uint64_t j = i; j < i + batch_size && j < num; ++j) {
+      for (uint64_t j = i; j < i+batch_size && j < num; ++j) {
         reader.Prepare(Slice(reinterpret_cast<char*>(&keys[j]), 16));
       }
-      for (uint64_t j = i; j < i + batch_size && j < num; ++j) {
+      for (uint64_t j = i; j < i+batch_size && j < num; ++j) {
         reader.Get(r_options, Slice(reinterpret_cast<char*>(&keys[j]), 16),
                    &get_context, nullptr);
       }
@@ -521,8 +515,8 @@ void ReadKeys(uint64_t num, uint32_t batch_size) {
   }
   float time_per_op = (env->NowMicros() - start_time) * 1.0f / num;
   fprintf(stderr,
-          "Time taken per op is %.3fus (%.1f Mqps) with batch size of %u\n",
-          time_per_op, 1.0 / time_per_op, batch_size);
+      "Time taken per op is %.3fus (%.1f Mqps) with batch size of %u\n",
+      time_per_op, 1.0 / time_per_op, batch_size);
 }
 }  // namespace.
 
@@ -534,11 +528,10 @@ TEST_F(CuckooReaderTest, TestReadPerformance) {
   // These numbers are chosen to have a hash utilization % close to
   // 0.9, 0.75, 0.6 and 0.5 respectively.
   // They all create 128 M buckets.
-  std::vector<uint64_t> nums = {120 * 1024 * 1024, 100 * 1024 * 1024,
-                                80 * 1024 * 1024, 70 * 1024 * 1024};
+  std::vector<uint64_t> nums = {120*1024*1024, 100*1024*1024, 80*1024*1024,
+    70*1024*1024};
 #ifndef NDEBUG
-  fprintf(
-      stdout,
+  fprintf(stdout,
       "WARNING: Not compiled with DNDEBUG. Performance tests may be slow.\n");
 #endif
   for (uint64_t num : nums) {
@@ -560,7 +553,6 @@ TEST_F(CuckooReaderTest, TestReadPerformance) {
 
 int main(int argc, char** argv) {
   if (ROCKSDB_NAMESPACE::port::kLittleEndian) {
-    ROCKSDB_NAMESPACE::port::InstallStackTraceHandler();
     ::testing::InitGoogleTest(&argc, argv);
     ParseCommandLineFlags(&argc, &argv, true);
     return RUN_ALL_TESTS();
@@ -572,3 +564,12 @@ int main(int argc, char** argv) {
 
 #endif  // GFLAGS.
 
+#else
+#include <stdio.h>
+
+int main(int /*argc*/, char** /*argv*/) {
+  fprintf(stderr, "SKIPPED as Cuckoo table is not supported in ROCKSDB_LITE\n");
+  return 0;
+}
+
+#endif  // ROCKSDB_LITE
