@@ -30,6 +30,7 @@ use std::borrow::Cow;
 use std::env;
 use std::ffi::{CStr, CString};
 use std::io::Write;
+use std::mem;
 use std::path::PathBuf;
 use std::ptr;
 use std::slice;
@@ -221,10 +222,49 @@ unsafe extern "C" fn CmpName(arg: *mut c_void) -> *const c_char {
     cstrp!("foo")
 }
 
-// Custom compaction filter
+// Custom filter policy
 
 static mut fake_filter_result: c_uchar = 1;
 
+unsafe extern "C" fn FilterDestroy(arg: *mut c_void) {}
+
+unsafe extern "C" fn FilterName(arg: *mut c_void) -> *const c_char {
+    cstrp!("TestFilter")
+}
+
+unsafe extern "C" fn FilterCreate(
+    arg: *mut c_void,
+    key_array: *const *const c_char,
+    key_length_array: *const size_t,
+    num_keys: c_int,
+    filter_length: *mut size_t,
+) -> *mut c_char {
+    *filter_length = 4;
+    let result = malloc(4);
+    memcpy(result, cstrp!("fake") as *const c_void, 4);
+    result as *mut c_char
+}
+
+unsafe extern "C" fn FilterKeyMatch(
+    arg: *mut c_void,
+    key: *const c_char,
+    length: size_t,
+    filter: *const c_char,
+    filter_length: size_t,
+) -> c_uchar {
+    CheckCondition!(filter_length == 4);
+    CheckCondition!(
+        memcmp(
+            filter as *const c_void,
+            cstrp!("fake") as *const c_void,
+            filter_length
+        ) == 0
+    );
+    fake_filter_result
+}
+
+// Custom compaction filter
+
 unsafe extern "C" fn CFilterDestroy(arg: *mut c_void) {}
 
 unsafe extern "C" fn CFilterName(arg: *mut c_void) -> *const c_char {
@@ -244,15 +284,15 @@ unsafe extern "C" fn CFilterFilter(
 ) -> c_uchar {
     if key_length == 3 {
         if memcmp(
-            key.cast::<c_void>(),
-            cstrp!("bar").cast::<c_void>(),
+            mem::transmute(key),
+            mem::transmute(cstrp!("bar")),
             key_length,
         ) == 0
         {
             return 1;
         } else if memcmp(
-            key.cast::<c_void>(),
-            cstrp!("baz").cast::<c_void>(),
+            mem::transmute(key),
+            mem::transmute(cstrp!("baz")),
             key_length,
         ) == 0
         {
@@ -394,7 +434,7 @@ fn ffi() {
         let mut err: *mut c_char = ptr::null_mut();
         let run: c_int = -1;
 
-        let test_uuid = Uuid::new_v4().simple();
+        let test_uuid = Uuid::new_v4().to_simple();
 
         let dbname = {
             let mut dir = GetTempDir();
@@ -434,10 +474,10 @@ fn ffi() {
         rocksdb_block_based_options_set_block_cache(table_options, cache);
         rocksdb_options_set_block_based_table_factory(options, table_options);
 
-        let no_compression = rocksdb_no_compression as c_int;
-        rocksdb_options_set_compression(options, no_compression);
+        let no_compression = rocksdb_no_compression;
+        rocksdb_options_set_compression(options, no_compression as i32);
         rocksdb_options_set_compression_options(options, -14, -1, 0, 0);
-        let mut compression_levels = vec![
+        let compression_levels = vec![
             no_compression,
             no_compression,
             no_compression,
@@ -445,7 +485,7 @@ fn ffi() {
         ];
         rocksdb_options_set_compression_per_level(
             options,
-            compression_levels.as_mut_ptr(),
+            mem::transmute(compression_levels.as_ptr()),
             compression_levels.len() as size_t,
         );
 
@@ -561,7 +601,7 @@ fn ffi() {
             let mut pos: c_int = 0;
             rocksdb_writebatch_iterate(
                 wb,
-                (&mut pos as *mut c_int).cast::<c_void>(),
+                mem::transmute(&mut pos),
                 Some(CheckPut),
                 Some(CheckDel),
             );
@@ -751,8 +791,20 @@ fn ffi() {
 
         StartPhase("filter");
         for run in 0..2 {
+            // First run uses custom filter, second run uses bloom filter
             CheckNoError!(err);
-            let mut policy: *mut rocksdb_filterpolicy_t = rocksdb_filterpolicy_create_bloom(10.0);
+            let mut policy: *mut rocksdb_filterpolicy_t = if run == 0 {
+                rocksdb_filterpolicy_create(
+                    ptr::null_mut(),
+                    Some(FilterDestroy),
+                    Some(FilterCreate),
+                    Some(FilterKeyMatch),
+                    None,
+                    Some(FilterName),
+                )
+            } else {
+                rocksdb_filterpolicy_create_bloom(10)
+            };
 
             rocksdb_block_based_options_set_filter_policy(table_options, policy);
 
@@ -1072,7 +1124,7 @@ fn ffi() {
                 rocksdb_slicetransform_create_fixed_prefix(3),
             );
             rocksdb_options_set_hash_skip_list_rep(options, 5000, 4, 4);
-            rocksdb_options_set_plain_table_factory(options, 4, 10, 0.75, 16, 0, 0, 0, 0);
+            rocksdb_options_set_plain_table_factory(options, 4, 10, 0.75, 16);
             rocksdb_options_set_allow_concurrent_memtable_write(options, 0);
 
             db = rocksdb_open(options, dbname, &mut err);
